embassy-stm32

Crates

git

Versions

stm32h7b0zb

Flavors

ExtremesDetector

Struct ExtremesDetector 

pub struct ExtremesDetector<'a, 'd, T, M>
where T: Instance, M: FilterMarker,
{ /* private fields */ }
Extremes (min/max) detector of a filter.

Implementations

Source

impl<'a, 'd, T, M> ExtremesDetector<'a, 'd, T, M>
where T: Instance, M: FilterMarker,

pub fn assign_transceivers<const N: usize>( &mut self, transceivers: [&dyn TransceiverTrait<T, Enabled>; N], )
where [(); N]: NonEmpty,

Assign provided transceivers to this extremes detector

pub fn read_maxima(&mut self) -> ResultExtreme

Reads the extremes detector maximum value and its corresponding channel. Reading this resets the register value to 0x800000 and clears the channel field.

pub fn read_minima(&mut self) -> ResultExtreme

Reads the extremes detector minimum value and its corresponding channel. Reading this resets the register value to 0x7FFFFF and clears the channel field.